#!/bin/ksh

ECHO="/bin/echo"

$ECHO "   "
$ECHO "Install WebSphere Commerce 5.4.0.1 Business Edition Fixpack"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "   "


# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <was_home> <wc_application_home>"
   $ECHO "where <was_home> is the directory where the IBM WebSphere Application Server(WAS) is installed"
   $ECHO "and <wc_application_home> is the directory where your Application is installed in the installedApps directory"
   $ECHO "Example: ./install_was.sh /opt/WebSphere/AppServer /opt/WebSphere/AppServer/installedApps/WC_Enterprise_App_[instance].ear"
}


# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WC_APPLICATION_HOME ] && val=2 && [ -d $WAS_HOME ]
   then
#   	$ECHO "---- Components path check passed -----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "Invalid WC_APPLICATION_HOME directory."
	      ;;
	   2) $ECHO "Invalid WAS_HOME directory."
	      ;;
	esac
   fi

   return $FALSE
}


# checks if required files exist.
check_files() {
local val=1

   if [ -f $WAS_HOME/java/jre/bin/java ] && val=2 && \
      [ -f ./WCfixpackBE5401_was_SUN.jar ] && val=3 && \
      [ -f ./Delta.jar ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: $WAS_HOME/java/jre/bin/java"
	      ;;
	   2) $ECHO "The following file does not exist: $WC_PTF"
	      ;;
	   3) $ECHO "The following file does not exist: $DELTA_JAR"
	      ;;
	esac
   fi

   return $FALSE;
}


# make service directories
make_service_dir() {

   if [ -d $WC_SERVICE_DIR ]; then
   	if [ -d $WC_FIXPACK_DIR ]; then
	   if [ -d $WC_FP5401_DIR ]; then
	      return
	   else
	      mkdir $WC_FP5401_DIR
	   fi
	else
	   mkdir $WC_FIXPACK_DIR
	   mkdir $WC_FP5401_DIR
	fi
   else
      mkdir $WC_SERVICE_DIR
      mkdir $WC_FIXPACK_DIR
      mkdir $WC_FP5401_DIR
   fi
}

# beginning of script.
#clear

TRUE=0
FALSE=1

WC_PTF="WCfixpackBE5401_was_SUN.jar"
DELTA_JAR="Delta.jar"


#ensure correct number of arguments provided.
if [ $# -ne 2 ]; then
   print_usage
   exit 0
else
   WC_APPLICATION_HOME=$2
   WAS_HOME=$1
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi


WC_SERVICE_DIR="$WC_APPLICATION_HOME/service"
WC_FIXPACK_DIR="$WC_APPLICATION_HOME/service/fixpack"
WC_FP5401_DIR="$WC_APPLICATION_HOME/service/fixpack/5401"


# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi


# make service directories
make_service_dir
$ECHO "main - service directories exist/created."

# Install WebSphere Commerce 5.4.0.1 Business Edition Fixpack, SUN
$ECHO "main - Installing Fixpack."

$WAS_HOME/java/jre/bin/java -jar $WC_PTF -TargetDir $WC_APPLICATION_HOME -backupJar $WC_FP5401_DIR/WCfixpackBE5401_was_SUN_backup.jar -log $WC_FP5401_DIR/WCfixpackBE5401_was_SUN.log -SkipVer

$ECHO "main - installing fixpack complete."
$ECHO "Please review the installation guide for any additional instructions."

exit 0
